#
# RPM spec file for Dan Bernstein's qmail package
#
# $Id: qmail.spec,v 1.11 2004/11/10 20:10:55 charlieb Exp $
#
Summary: A modern, fast, secure replacement for sendmail
%define name qmail
Name: %{name}
%define version 1.03
%define release 13
Version: %{version}
Release: %{release}%{?dist}
License: Daniel J. Bernstein
Group: Networking/Daemons
Source: http://cr.yp.to/software/%{name}-%{version}.tar.gz
Patch0: qmail-1.03-echouser.patch
URL: http://cr.yp.to/%{name}.html
BuildRoot: /var/tmp/%{name}-%{version}-%{release}-buildroot
Provides: smtpdaemon
Requires: /bin/cut, /bin/grep, /usr/bin/id
Requires: /usr/sbin/useradd, /usr/sbin/groupadd
BuildRequires: groff
Conflicts: sendmail
AutoReqProv: no

%description
qmail is a secure, reliable, efficient, simple message transfer agent.
It is meant as a replacement for the entire sendmail-binmail system on
typical Internet-connected UNIX hosts.

Secure: Security isn't just a goal, but an absolute requirement. Mail
delivery is critical for users; it cannot be turned off, so it must be
completely secure. (This is why I started writing qmail: I was sick of
the security holes in sendmail and other MTAs.)

Reliable: qmail's straight-paper-path philosophy guarantees that a
message, once accepted into the system, will never be lost. qmail also
optionally supports maildir, a new, super-reliable user mailbox format.
Maildirs, unlike mbox files and mh folders, won't be corrupted if the
system crashes during delivery. Even better, not only can a user safely
read his mail over NFS, but any number of NFS clients can deliver mail
to him at the same time.

Efficient: On a Pentium under BSD/OS, qmail can easily sustain 200000
local messages per day---that's separate messages injected and delivered
to mailboxes in a real test! Although remote deliveries are inherently
limited by the slowness of DNS and SMTP, qmail overlaps 20 simultaneous
deliveries by default, so it zooms quickly through mailing lists. (This
is why I finished qmail: I had to get a big mailing list set up.)

Simple: qmail is vastly smaller than any other Internet MTA. Some
reasons why: (1) Other MTAs have separate forwarding, aliasing, and
mailing list mechanisms. qmail has one simple forwarding mechanism
that lets users handle their own mailing lists. (2) Other MTAs offer a
spectrum of delivery modes, from fast+unsafe to slow+queued. qmail-send
is instantly triggered by new items in the queue, so the qmail system has
just one delivery mode: fast+queued. (3) Other MTAs include, in effect,
a specialized version of inetd that watches the load average. qmail's
design inherently limits the machine load, so qmail-smtpd can safely
run from your system's inetd.

Replacement for sendmail: qmail supports host and user masquerading,
full host hiding, virtual domains, null clients, list-owner rewriting,
relay control, double-bounce recording, arbitrary RFC 822 address lists,
cross-host mailing list loop detection, per-recipient checkpointing,
downed host backoffs, independent message retry schedules, etc. qmail
also includes a drop-in ``sendmail'' wrapper so that it will be used
transparently by your current UAs.

%changelog
* Sun Apr 29 2007 Shad L. Lords <slords@mail.com>
- Clean up spec so package can be built by koji/plague

* Thu Dec 07 2006 Shad L. Lords <slords@mail.com>
- Update to new release naming.  No functional changes.
- Make Packager generic

* Wed Nov 30 2005 Gordon Rowell <gordonr@gormand.com.au> 1.03-13
- Bump release number only

* Wed Nov 10 2004 Charlie Brady <charlieb@e-smith.com> 1.03-12
- Add pre section which adds users and groups as required. We
  shouldn't be trying to do that at build time, but we must do
  it at install time. Change build time to just check the ids.

* Fri Aug 27 2004 Charlie Brady <charlieb@e-smith.com> 1.03-11
- Remove require of non-existent qmail-users RPM

* Wed Oct 29 2003 Charlie Brady <charlieb@e-smith.com> 1.03-10
- Use a compiler configuration which works around the glibc/errno
  problem.

* Mon Aug 18 2003 Charlie Brady <charlieb@e-smith.com> 1.03-09
- Change install so that no patch to the build tools is necessary.

* Mon Apr 21 2003 Gordon Rowell <gordon_rowell@mitel.com>
- Added Requires: qmail-users (added in modified setup RPM) [gordonr 8368]
- Removed user creation/deletion from %pre/%post/%postun [gordonr 8368]

* Wed Apr 17 2003 Gordon Rowell <gordon_rowell@mitel.com>
- [1.03-07]
- Added path to calls to cut to remove log noise [gordonr 8353]

* Thu Feb  8 2001 Adrian Chung <adrianc@e-smith.com>
- [1.03-06]
- Rolling release number for GPG signing.

* Mon Feb 5 2001 Peter Samuel <peters@e-smith.com>
- [1.03-05]
- Now installs in its own root area prior to creating binary RPM.
- Better checks for uid and gid values.

* Fri Dec 22 2000 Peter Samuel <peters@e-smith.com>
- [1.03-4]
- symlinks to /var/qmail/bin/sendmail are now part of the package
  instead of part of the post install script.

* Mon Dec 18 2000 Peter Samuel <peters@e-smith.com>
- [1.03-3]
- Removed DNS patch. AOL seems to be behaving itself.
- Minor format cleanups to spec file.
- Postinstall now ensures existing files have correct ownerships.

%prep
## # Prior to building the package, ensure that the qmail users and groups
## # exist and have the correct uid and gid information. This avoids uid
## # and gid conflicts between installations.
## 
## # GIDs
## nofiles=400
## qmail=401
## 
## # UIDs
## alias=400
## qmaild=401
## qmaill=402
## qmailp=403
## qmailq=404
## qmailr=405
## qmails=406
## 
## group_check()
## {
##     x=$(grep "^$1:" /etc/group | /usr/bin/cut -d: -f3 2>/dev/null)
##     if [ "$x" != "$2" ]
##     then
## 	echo group $1 should be $2 but is $x
## 	exit 1
##     fi
## }
## 
## group_check nofiles $nofiles
## group_check qmail   $qmail
## 
## user_check()
## {
##     x=$(id -u $1)
##     if [ "$x" != "$2" ]
##     then
## 	echo user $1 should be $2 but is $x
## 	exit 1
##     fi
## }
## 
## user_check alias  $alias  $nofiles /var/qmail/alias /bin/false
## user_check qmaild $qmaild $nofiles /var/qmail       /bin/false
## user_check qmaill $qmaill $nofiles /var/qmail       /bin/false
## user_check qmailp $qmailp $nofiles /var/qmail       /bin/false
## user_check qmailq $qmailq $qmail   /var/qmail       /bin/false
## user_check qmailr $qmailr $qmail   /var/qmail       /bin/false
## user_check qmails $qmails $qmail   /var/qmail       /bin/false

%setup
%patch0 -p1

%build
echo gcc -O2 --include /usr/include/errno.h > conf-cc
make

%install
rm -rf $RPM_BUILD_ROOT
make it man

# Create the relocated installation directory.
# We can't run ./install, as it requires root, and
# dirties the build system. Instead, we just do the
# equivalent steps
mkdir -p $RPM_BUILD_ROOT/var/qmail
for i in alias control users bin boot doc man queue
do
  mkdir $RPM_BUILD_ROOT/var/qmail/$i
done
for i in pid intd todo bounce mess info local remote lock
do
  mkdir $RPM_BUILD_ROOT/var/qmail/queue/$i
done
for i in $(seq 0 22)
do
  mkdir $RPM_BUILD_ROOT/var/qmail/queue/mess/$i
  mkdir $RPM_BUILD_ROOT/var/qmail/queue/info/$i
  mkdir $RPM_BUILD_ROOT/var/qmail/queue/local/$i
  mkdir $RPM_BUILD_ROOT/var/qmail/queue/remote/$i
done
for i in \
  qmail-queue qmail-lspawn qmail-start qmail-getpw qmail-local \
  qmail-remote qmail-rspawn qmail-clean qmail-send splogger \
  qmail-newu qmail-newmrh qmail-pw2u qmail-inject predate \
  datemail mailsubj qmail-showctl qmail-qread qmail-qstat \
  qmail-tcpto qmail-tcpok qmail-pop3d qmail-popup qmail-qmqpc \
  qmail-qmqpd qmail-qmtpd qmail-smtpd sendmail tcp-env qreceipt \
  qsmhook qbiff forward preline condredirect \
  bouncesaying except maildirmake maildir2mbox maildirwatch \
  qail elq pinq
do
  mv $i $RPM_BUILD_ROOT/var/qmail/bin/
done

for i in \
  home home+df proc proc+df binm1 binm1+df \
  binm2 binm2+df binm3 binm3+df
do
  mv $i $RPM_BUILD_ROOT/var/qmail/boot
done

for i in \
  FAQ UPGRADE SENDMAIL INSTALL INSTALL.alias INSTALL.ctl \
  INSTALL.ids INSTALL.maildir INSTALL.mbox INSTALL.vsm \
  TEST.deliver TEST.receive REMOVE.sendmail REMOVE.binmail \
  PIC.local2alias PIC.local2ext PIC.local2local PIC.local2rem \
  PIC.local2virt PIC.nullclient PIC.relaybad PIC.relaygood \
  PIC.rem2local
do
  mv $i $RPM_BUILD_ROOT/var/qmail/doc/
done

for i in 1 5 7 8
do
  mkdir $RPM_BUILD_ROOT/var/qmail/man/cat$i
  mkdir $RPM_BUILD_ROOT/var/qmail/man/man$i
done
for i in *.1
do
  mv $i $RPM_BUILD_ROOT/var/qmail/man/man1/
  mv $(echo $i | sed s/1/0/) $RPM_BUILD_ROOT/var/qmail/man/cat1/
done

for i in *.5
do
  mv $i $RPM_BUILD_ROOT/var/qmail/man/man5/
  mv $(echo $i | sed s/5/0/) $RPM_BUILD_ROOT/var/qmail/man/cat5/
done

for i in *.7
do
  mv $i $RPM_BUILD_ROOT/var/qmail/man/man7/
  mv $(echo $i | sed s/7/0/) $RPM_BUILD_ROOT/var/qmail/man/cat7/
done

for i in *.8
do
  mv $i $RPM_BUILD_ROOT/var/qmail/man/man8/
  mv $(echo $i | sed s/8/0/) $RPM_BUILD_ROOT/var/qmail/man/cat8/
done

mkfifo $RPM_BUILD_ROOT/var/qmail/queue/lock/trigger
dd bs=1024 count=1 if=/dev/zero of=$RPM_BUILD_ROOT/var/qmail/queue/lock/tcpto
dd bs=1024 count=0 if=/dev/zero of=$RPM_BUILD_ROOT/var/qmail/queue/lock/sendmutex

# Create the relative installation directories for the symlinks.

mkdir -p $RPM_BUILD_ROOT/usr/lib
mkdir -p $RPM_BUILD_ROOT/usr/sbin
ln -s /var/qmail/bin/sendmail $RPM_BUILD_ROOT/usr/lib/sendmail
ln -s /var/qmail/bin/sendmail $RPM_BUILD_ROOT/usr/sbin/sendmail

%pre
# Prior to installing the package, ensure that the qmail users and groups
# exist and have the correct uid and gid information. This ensures that
# uid and gid values match the values which are compiled into the binaries

# GIDs
nofiles=400
qmail=401

# UIDs
alias=400
qmaild=401
qmaill=402
qmailp=403
qmailq=404
qmailr=405
qmails=406

group_check()
{
    if grep "^$1:" /etc/group > /dev/null 2>&1
    then
	if [ $(grep "^$1:" /etc/group | /usr/bin/cut -d: -f3) != $2 ]
	then
	    /usr/sbin/groupdel $1
	    /usr/sbin/groupadd -g $2 $1
	fi
    else
	/usr/sbin/groupadd -g $2 $1
    fi
}

group_check nofiles $nofiles
group_check qmail   $qmail

user_check()
{
    if grep "^$1:" /etc/passwd > /dev/null 2>&1
    then
	if [ $(grep "^$1:" /etc/passwd | /usr/bin/cut -d: -f3,4) != "$2:$3" ]
	then
	    /usr/sbin/userdel $1
	    /usr/sbin/useradd -u $2 -M -g $3 -d $4 -s $5 $1
	fi
    else
	/usr/sbin/useradd -u $2 -M -g $3 -d $4 -s $5 $1
    fi
}

user_check alias  $alias  $nofiles /var/qmail/alias /bin/false
user_check qmaild $qmaild $nofiles /var/qmail       /bin/false
user_check qmaill $qmaill $nofiles /var/qmail       /bin/false
user_check qmailp $qmailp $nofiles /var/qmail       /bin/false
user_check qmailq $qmailq $qmail   /var/qmail       /bin/false
user_check qmailr $qmailr $qmail   /var/qmail       /bin/false
user_check qmails $qmails $qmail   /var/qmail       /bin/false


%clean
rm -rf $RPM_BUILD_ROOT

%files
%attr(755,root,qmail)   %dir /var/qmail
%attr(2755,alias,qmail) %dir /var/qmail/alias
%attr(755,root,qmail)   %dir /var/qmail/control
%attr(755,root,qmail)   %dir /var/qmail/users
%attr(755,root,qmail)   %dir /var/qmail/bin
%attr(755,root,qmail)   %dir /var/qmail/boot
%attr(755,root,qmail)   %dir /var/qmail/doc
%attr(755,root,qmail)   %dir /var/qmail/man
%attr(755,root,qmail)   %dir /var/qmail/man/cat1
%attr(755,root,qmail)   %dir /var/qmail/man/cat5
%attr(755,root,qmail)   %dir /var/qmail/man/cat7
%attr(755,root,qmail)   %dir /var/qmail/man/cat8
%attr(755,root,qmail)   %dir /var/qmail/man/man1
%attr(755,root,qmail)   %dir /var/qmail/man/man5
%attr(755,root,qmail)   %dir /var/qmail/man/man7
%attr(755,root,qmail)   %dir /var/qmail/man/man8
%attr(750,qmailq,qmail) %dir /var/qmail/queue
%attr(700,qmailq,qmail) %dir /var/qmail/queue/pid
%attr(700,qmailq,qmail) %dir /var/qmail/queue/intd
%attr(750,qmailq,qmail) %dir /var/qmail/queue/todo
%attr(700,qmails,qmail) %dir /var/qmail/queue/bounce
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/0
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/1
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/2
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/3
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/4
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/5
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/6
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/7
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/8
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/9
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/10
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/11
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/12
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/13
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/14
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/15
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/16
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/17
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/18
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/19
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/20
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/21
%attr(750,qmailq,qmail) %dir /var/qmail/queue/mess/22
%attr(700,qmails,qmail) %dir /var/qmail/queue/info
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/0
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/1
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/2
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/3
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/4
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/5
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/6
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/7
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/8
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/9
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/10
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/11
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/12
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/13
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/14
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/15
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/16
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/17
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/18
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/19
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/20
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/21
%attr(700,qmails,qmail) %dir /var/qmail/queue/info/22
%attr(700,qmails,qmail) %dir /var/qmail/queue/local
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/0
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/1
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/2
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/3
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/4
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/5
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/6
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/7
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/8
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/9
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/10
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/11
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/12
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/13
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/14
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/15
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/16
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/17
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/18
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/19
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/20
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/21
%attr(700,qmails,qmail) %dir /var/qmail/queue/local/22
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/0
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/1
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/2
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/3
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/4
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/5
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/6
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/7
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/8
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/9
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/10
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/11
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/12
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/13
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/14
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/15
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/16
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/17
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/18
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/19
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/20
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/21
%attr(700,qmails,qmail) %dir /var/qmail/queue/remote/22
%attr(750,qmailq,qmail) %dir /var/qmail/queue/lock
%attr(4711,qmailq,qmail)     /var/qmail/bin/qmail-queue
%attr(700,root,qmail)        /var/qmail/bin/qmail-lspawn
%attr(700,root,qmail)        /var/qmail/bin/qmail-start
%attr(711,root,qmail)        /var/qmail/bin/qmail-getpw
%attr(711,root,qmail)        /var/qmail/bin/qmail-local
%attr(711,root,qmail)        /var/qmail/bin/qmail-remote
%attr(711,root,qmail)        /var/qmail/bin/qmail-rspawn
%attr(711,root,qmail)        /var/qmail/bin/qmail-clean
%attr(711,root,qmail)        /var/qmail/bin/qmail-send
%attr(711,root,qmail)        /var/qmail/bin/splogger
%attr(700,root,qmail)        /var/qmail/bin/qmail-newu
%attr(700,root,qmail)        /var/qmail/bin/qmail-newmrh
%attr(711,root,qmail)        /var/qmail/bin/qmail-pw2u
%attr(755,root,qmail)        /var/qmail/bin/qmail-inject
%attr(755,root,qmail)        /var/qmail/bin/predate
%attr(755,root,qmail)        /var/qmail/bin/datemail
%attr(755,root,qmail)        /var/qmail/bin/mailsubj
%attr(755,root,qmail)        /var/qmail/bin/qmail-showctl
%attr(755,root,qmail)        /var/qmail/bin/qmail-qread
%attr(755,root,qmail)        /var/qmail/bin/qmail-qstat
%attr(755,root,qmail)        /var/qmail/bin/qmail-tcpto
%attr(755,root,qmail)        /var/qmail/bin/qmail-tcpok
%attr(755,root,qmail)        /var/qmail/bin/qmail-pop3d
%attr(711,root,qmail)        /var/qmail/bin/qmail-popup
%attr(755,root,qmail)        /var/qmail/bin/qmail-qmqpc
%attr(755,root,qmail)        /var/qmail/bin/qmail-qmqpd
%attr(755,root,qmail)        /var/qmail/bin/qmail-qmtpd
%attr(755,root,qmail)        /var/qmail/bin/qmail-smtpd
%attr(755,root,qmail)        /var/qmail/bin/sendmail
%attr(755,root,qmail)        /var/qmail/bin/tcp-env
%attr(755,root,qmail)        /var/qmail/bin/qreceipt
%attr(755,root,qmail)        /var/qmail/bin/qsmhook
%attr(755,root,qmail)        /var/qmail/bin/qbiff
%attr(755,root,qmail)        /var/qmail/bin/forward
%attr(755,root,qmail)        /var/qmail/bin/preline
%attr(755,root,qmail)        /var/qmail/bin/condredirect
%attr(755,root,qmail)        /var/qmail/bin/bouncesaying
%attr(755,root,qmail)        /var/qmail/bin/except
%attr(755,root,qmail)        /var/qmail/bin/maildirmake
%attr(755,root,qmail)        /var/qmail/bin/maildir2mbox
%attr(755,root,qmail)        /var/qmail/bin/maildirwatch
%attr(755,root,qmail)        /var/qmail/bin/qail
%attr(755,root,qmail)        /var/qmail/bin/elq
%attr(755,root,qmail)        /var/qmail/bin/pinq
%attr(755,root,qmail)        /var/qmail/boot/home
%attr(755,root,qmail)        /var/qmail/boot/home+df
%attr(755,root,qmail)        /var/qmail/boot/proc
%attr(755,root,qmail)        /var/qmail/boot/proc+df
%attr(755,root,qmail)        /var/qmail/boot/binm1
%attr(755,root,qmail)        /var/qmail/boot/binm1+df
%attr(755,root,qmail)        /var/qmail/boot/binm2
%attr(755,root,qmail)        /var/qmail/boot/binm2+df
%attr(755,root,qmail)        /var/qmail/boot/binm3
%attr(755,root,qmail)        /var/qmail/boot/binm3+df
%attr(644,root,qmail)        /var/qmail/doc/FAQ
%attr(644,root,qmail)        /var/qmail/doc/UPGRADE
%attr(644,root,qmail)        /var/qmail/doc/SENDMAIL
%attr(644,root,qmail)        /var/qmail/doc/INSTALL
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.alias
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.ctl
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.ids
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.maildir
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.mbox
%attr(644,root,qmail)        /var/qmail/doc/INSTALL.vsm
%attr(644,root,qmail)        /var/qmail/doc/TEST.deliver
%attr(644,root,qmail)        /var/qmail/doc/TEST.receive
%attr(644,root,qmail)        /var/qmail/doc/REMOVE.sendmail
%attr(644,root,qmail)        /var/qmail/doc/REMOVE.binmail
%attr(644,root,qmail)        /var/qmail/doc/PIC.local2alias
%attr(644,root,qmail)        /var/qmail/doc/PIC.local2ext
%attr(644,root,qmail)        /var/qmail/doc/PIC.local2local
%attr(644,root,qmail)        /var/qmail/doc/PIC.local2rem
%attr(644,root,qmail)        /var/qmail/doc/PIC.local2virt
%attr(644,root,qmail)        /var/qmail/doc/PIC.nullclient
%attr(644,root,qmail)        /var/qmail/doc/PIC.relaybad
%attr(644,root,qmail)        /var/qmail/doc/PIC.relaygood
%attr(644,root,qmail)        /var/qmail/doc/PIC.rem2local
%attr(644,root,qmail)        /var/qmail/man/cat1/forward.0
%attr(644,root,qmail)        /var/qmail/man/cat1/condredirect.0
%attr(644,root,qmail)        /var/qmail/man/cat1/bouncesaying.0
%attr(644,root,qmail)        /var/qmail/man/cat1/except.0
%attr(644,root,qmail)        /var/qmail/man/cat1/maildirmake.0
%attr(644,root,qmail)        /var/qmail/man/cat1/maildir2mbox.0
%attr(644,root,qmail)        /var/qmail/man/cat1/maildirwatch.0
%attr(644,root,qmail)        /var/qmail/man/cat1/mailsubj.0
%attr(644,root,qmail)        /var/qmail/man/cat1/qreceipt.0
%attr(644,root,qmail)        /var/qmail/man/cat1/qbiff.0
%attr(644,root,qmail)        /var/qmail/man/cat1/preline.0
%attr(644,root,qmail)        /var/qmail/man/cat1/tcp-env.0
%attr(644,root,qmail)        /var/qmail/man/cat5/addresses.0
%attr(644,root,qmail)        /var/qmail/man/cat5/envelopes.0
%attr(644,root,qmail)        /var/qmail/man/cat5/maildir.0
%attr(644,root,qmail)        /var/qmail/man/cat5/mbox.0
%attr(644,root,qmail)        /var/qmail/man/cat5/dot-qmail.0
%attr(644,root,qmail)        /var/qmail/man/cat5/qmail-control.0
%attr(644,root,qmail)        /var/qmail/man/cat5/qmail-header.0
%attr(644,root,qmail)        /var/qmail/man/cat5/qmail-log.0
%attr(644,root,qmail)        /var/qmail/man/cat5/qmail-users.0
%attr(644,root,qmail)        /var/qmail/man/cat5/tcp-environ.0
%attr(644,root,qmail)        /var/qmail/man/cat7/forgeries.0
%attr(644,root,qmail)        /var/qmail/man/cat7/qmail-limits.0
%attr(644,root,qmail)        /var/qmail/man/cat7/qmail.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-local.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-lspawn.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-getpw.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-remote.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-rspawn.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-clean.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-send.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-start.0
%attr(644,root,qmail)        /var/qmail/man/cat8/splogger.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-queue.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-inject.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-showctl.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-newmrh.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-newu.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-pw2u.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-qread.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-qstat.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-tcpok.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-tcpto.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-pop3d.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-popup.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-qmqpc.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-qmqpd.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-qmtpd.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-smtpd.0
%attr(644,root,qmail)        /var/qmail/man/cat8/qmail-command.0
%attr(644,root,qmail)        /var/qmail/man/man1/forward.1
%attr(644,root,qmail)        /var/qmail/man/man1/condredirect.1
%attr(644,root,qmail)        /var/qmail/man/man1/bouncesaying.1
%attr(644,root,qmail)        /var/qmail/man/man1/except.1
%attr(644,root,qmail)        /var/qmail/man/man1/maildirmake.1
%attr(644,root,qmail)        /var/qmail/man/man1/maildir2mbox.1
%attr(644,root,qmail)        /var/qmail/man/man1/maildirwatch.1
%attr(644,root,qmail)        /var/qmail/man/man1/mailsubj.1
%attr(644,root,qmail)        /var/qmail/man/man1/qreceipt.1
%attr(644,root,qmail)        /var/qmail/man/man1/qbiff.1
%attr(644,root,qmail)        /var/qmail/man/man1/preline.1
%attr(644,root,qmail)        /var/qmail/man/man1/tcp-env.1
%attr(644,root,qmail)        /var/qmail/man/man5/addresses.5
%attr(644,root,qmail)        /var/qmail/man/man5/envelopes.5
%attr(644,root,qmail)        /var/qmail/man/man5/maildir.5
%attr(644,root,qmail)        /var/qmail/man/man5/mbox.5
%attr(644,root,qmail)        /var/qmail/man/man5/dot-qmail.5
%attr(644,root,qmail)        /var/qmail/man/man5/qmail-control.5
%attr(644,root,qmail)        /var/qmail/man/man5/qmail-header.5
%attr(644,root,qmail)        /var/qmail/man/man5/qmail-log.5
%attr(644,root,qmail)        /var/qmail/man/man5/qmail-users.5
%attr(644,root,qmail)        /var/qmail/man/man5/tcp-environ.5
%attr(644,root,qmail)        /var/qmail/man/man7/forgeries.7
%attr(644,root,qmail)        /var/qmail/man/man7/qmail-limits.7
%attr(644,root,qmail)        /var/qmail/man/man7/qmail.7
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-local.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-lspawn.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-getpw.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-remote.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-rspawn.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-clean.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-send.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-start.8
%attr(644,root,qmail)        /var/qmail/man/man8/splogger.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-queue.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-inject.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-showctl.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-newmrh.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-newu.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-pw2u.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-qread.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-qstat.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-tcpok.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-tcpto.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-pop3d.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-popup.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-qmqpc.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-qmqpd.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-qmtpd.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-smtpd.8
%attr(644,root,qmail)        /var/qmail/man/man8/qmail-command.8
%attr(644,qmailr,qmail)      /var/qmail/queue/lock/tcpto
%attr(600,qmails,qmail)      /var/qmail/queue/lock/sendmutex
%attr(622,qmails,qmail)      /var/qmail/queue/lock/trigger
%attr(777,root,root)         /usr/lib/sendmail
%attr(777,root,root)         /usr/sbin/sendmail
